@@ -24,18 +24,12 @@
 #include <QGuiApplication>
 #include <QStandardPaths>
 #include <QThread>
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
-#include <private/qtx11extras_p.h>
-#else
-#include <QX11Info>
-#endif
+#include <QtGui/private/qtx11extras_p.h>
 
 #include <memory>
 
 using namespace KScreen;
 
-Q_DECLARE_METATYPE(org::kde::kscreen::Backend *)
-
 const int BackendManager::sMaxCrashCount = 4;
 
 BackendManager *BackendManager::sInstance = nullptr;
@@ -91,7 +85,7 @@ void BackendManager::initMethod()
 
         mResetCrashCountTimer.setSingleShot(true);
         mResetCrashCountTimer.setInterval(60000);
-        connect(&mResetCrashCountTimer, &QTimer::timeout, this, [=]() {
+        connect(&mResetCrashCountTimer, &QTimer::timeout, this, [this]() {
             mCrashCount = 0;
         });
     }
@@ -169,10 +163,7 @@ QFileInfoList BackendManager::listBackends()
     const QStringList paths = QCoreApplication::libraryPaths();
     QFileInfoList finfos;
     for (const QString &path : paths) {
-        const QDir dir(path + QStringLiteral("/kf" QT_STRINGIFY(QT_VERSION_MAJOR) "/kscreen/"),
-                       backendFilter,
-                       QDir::SortFlags(QDir::QDir::Name),
-                       QDir::NoDotAndDotDot | QDir::Files);
+        const QDir dir(path + QStringLiteral("/kf6/kscreen/"), backendFilter, QDir::SortFlags(QDir::QDir::Name), QDir::NoDotAndDotDot | QDir::Files);
         finfos.append(dir.entryInfoList());
     }
     return finfos;
@@ -404,3 +395,5 @@ void BackendManager::shutdownBackend()
         }
     }
 }
+
+#include "moc_backendmanager_p.cpp"
