@@ -3,8 +3,7 @@
 //
 // SPDX-License-Identifier: LGPL-2.1-or-later
 
-#ifndef ABSTRACTDPMSHELPER_H
-#define ABSTRACTDPMSHELPER_H
+#pragma once
 
 #include "dpms.h"
 #include <QObject>
@@ -25,12 +24,9 @@ public:
 
     bool isSupported()
     {
-        if (!m_supported.has_value()) {
-            blockUntilSupported();
-        }
-        Q_ASSERT(m_supported.has_value());
-        return *m_supported;
+        return m_supported;
     }
+
     void setSupported(bool supported)
     {
         if (m_supported != supported) {
@@ -58,12 +54,8 @@ Q_SIGNALS:
     void hasPendingChangesChanged(bool pendingChanges);
 
 private:
-    virtual void blockUntilSupported() {}
-
-    std::optional<bool> m_supported;
+    bool m_supported = false;
     bool m_hasPendingChanges = false;
 };
 
 }
-
-#endif
