@@ -1,20 +1,8 @@
-/*************************************************************************************
- *  Copyright 2014-2015 Sebastian Kügler <sebas@kde.org>                             *
- *                                                                                   *
- *  This library is free software; you can redistribute it and/or                    *
- *  modify it under the terms of the GNU Lesser General Public                       *
- *  License as published by the Free Software Foundation; either                     *
- *  version 2.1 of the License, or (at your option) any later version.               *
- *                                                                                   *
- *  This library is distributed in the hope that it will be useful,                  *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of                   *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU                *
- *  Lesser General Public License for more details.                                  *
- *                                                                                   *
- *  You should have received a copy of the GNU Lesser General Public                 *
- *  License along with this library; if not, write to the Free Software              *
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA       *
- *************************************************************************************/
+/*
+ *  SPDX-FileCopyrightText: 2014-2015 Sebastian Kügler <sebas@kde.org>
+ *
+ *  SPDX-License-Identifier: LGPL-2.1-or-later
+ */
 
 #include "waylandconfigreader.h"
 
@@ -44,7 +32,7 @@ void WaylandConfigReader::outputsFromConfig(const QString &configfile,
     QJsonObject json = jsonDoc.object();
 
     QJsonArray omap = json[QStringLiteral("outputs")].toArray();
-    Q_FOREACH (const QJsonValue &value, omap) {
+    for (const QJsonValue &value : omap) {
         const QVariantMap &output = value.toObject().toVariantMap();
         if (output[QStringLiteral("connected")].toBool()) {
             outputs << createOutputDevice(output, display);
@@ -106,7 +94,7 @@ OutputDeviceInterface *WaylandConfigReader::createOutputDevice(const QVariantMap
     QVariantList preferredModes = outputConfig[QStringLiteral("preferredModes")].toList();
 
     int mode_id = 0;
-    Q_FOREACH (const QVariant &_mode, outputConfig[QStringLiteral("modes")].toList()) {
+    for (const QVariant &_mode : outputConfig[QStringLiteral("modes")].toList()) {
         mode_id++;
         const QVariantMap &mode = _mode.toMap();
         OutputDeviceInterface::Mode m0;
@@ -162,7 +150,7 @@ QList<KWayland::Server::OutputInterface *> KScreen::WaylandConfigReader::createO
     };
 
     QList<KWayland::Server::OutputInterface *> outputs;
-    Q_FOREACH (const auto outputdevice, outputdevices) {
+    for (const auto outputdevice : outputdevices) {
         qDebug() << "New Output!";
         KWayland::Server::OutputInterface *output = display->createOutput(display);
 
@@ -171,7 +159,7 @@ QList<KWayland::Server::OutputInterface *> KScreen::WaylandConfigReader::createO
         output->setModel(outputdevice->model());
         // output->setUuid(outputdevice->uuid());
 
-        Q_FOREACH (const auto mode, outputdevice->modes()) {
+        for (const auto mode : outputdevice->modes()) {
             bool isCurrent = mode.flags.testFlag(OutputDeviceInterface::ModeFlag::Current);
             bool isPreferred = mode.flags.testFlag(OutputDeviceInterface::ModeFlag::Current);
             OutputInterface::ModeFlags flags;
